import * as globals from './globals.js';
import { onPortConnect, onPortDisconnect, addText } from './uiHelpers.js';

export async function connectToSerialPort(port, baud) {
    console.log("Connecting to port: ", port);
    await port.open({ baudRate: baud });
    onPortConnect()

    let buffer = ''
    globals.setEncoder(new TextEncoder());
    globals.setWriter(port.writable.getWriter());

    const textDecoder = new TextDecoderStream();
    const readableStreamClosed = port.readable.pipeTo(textDecoder.writable);
    globals.setReader(textDecoder.readable.getReader());

    const controller = new AbortController();
    const signal = controller.signal;
    try {
        globals.setPortConnected(true);
        while (globals.isPortConnected) {
            const { value, done } = await globals.reader.read({ signal });
            if (done || !port.readable) {
                break;
            }

            buffer += value;

            while (buffer.includes('\n')) {
                const newlineIndex = buffer.indexOf('\n');
                const line = buffer.slice(0, newlineIndex);
                buffer = buffer.slice(newlineIndex + 1);

                addText(line);
            }
        }
    } catch (error) {
        console.error('Error reading data from serial port:', error);
    } finally {
        // Port cleanup
        controller.abort();
        globals.writer.releaseLock();
        globals.reader.releaseLock();

        try {
            globals.reader.cancel();
        } catch (error) {
        }

        try {
            await readableStreamClosed;
        } catch (error) {
        }

        try {
            await readableStreamClosed;
        } catch (error) {
        }

        try {
            await port.close();
        } catch (error) {
            console.error("Error encountered closing port:", error);
        }
        onPortDisconnect()
    }
}

export function transmitContents(input) {
    const encoded_string = globals.encoder.encode(input + '\r')
    console.log("Binary Contents: ", encoded_string)
    globals.writer.write(encoded_string)
}
